@@ -50,10 +50,9 @@ class Query(ResourceBase):
         result["data"] = []
         query.get_result_stream(timeout=timeout).subscribe(
             on_next=lambda i: result["data"].append(i),
-            on_error=lambda e: print(f"error {e}"),  # todo better handling this error
+            on_error=lambda e: query.stop(),  # todo better handling this error
             on_completed=lambda: query.stop(),
         )
-
         return result
 
     def name(self, *args):
@@ -150,7 +149,7 @@ class Query(ResourceBase):
                     try:
                         record = json.loads(result)
                     except Exception as e:
-                        self._logger.warning(f"cannot load result from ws {result} {e}")
+                        self._logger.debug(f"cannot load result from ws {result} {e}")
                         continue
 
                     for index, col in enumerate(self.header()):
@@ -165,7 +164,7 @@ class Query(ResourceBase):
                     observer.on_next(record)
                 observer.on_complete()
             except Exception as e:
-                self._logger.error("failed to recieve data from websocket", e)
+                self._logger.debug("failed to recieve data from websocket", e)
                 observer.on_error(e)
 
         return __query_op
